@@ -119,7 +119,10 @@ BILL_ACTION_CLASSIFICATION_CHOICES = (
     ("hearing-held", "Public Hearing Held/Scheduled"),
     ("work-session", "Work Session Held/Scheduled"),
     ("sponsorship", "Authorship/Sponsorship Details"),
-    ("carried-over", "Carried Over from Previous Session")
+    ("carried-over", "Carried Over from Previous Session"),
+    ("reported-out-of-committee", "Reported Out of Committee"),
+    ("concurrence", "Sent for Concurrence")
+
 
 )
 BILL_ACTION_CLASSIFICATIONS = _keys(BILL_ACTION_CLASSIFICATION_CHOICES)
