@@ -298,9 +298,7 @@ class BaseImporter:
         for json_id, data in self._prepare_imports(data_items):
             obj_id, what = self.import_item(data)
             if not obj_id or not what:
-                self.logger.warning(
-                    f"Skipped {data} because it did not have an associated ID or type"
-                )
+                "Skipping data because it did not have an associated ID or type"
                 continue
             self.json_to_db_id[json_id] = obj_id
             record["records"][what].append(obj_id)
@@ -583,9 +581,9 @@ class BaseImporter:
             self.person_cache[cache_key] = ids.pop()
             errmsg = None
         elif not ids:
-            errmsg = f"no people returned for {spec}"
+            errmsg = "no people returned for spec"
         else:
-            errmsg = f"multiple people returned for {spec}"
+            errmsg = "multiple people returned for spec"
 
         # either raise or log error
         if errmsg:
