@@ -14,11 +14,16 @@ from openstates.utils.generic import _make_pseudo_id
 from openstates.exceptions import DuplicateItemError
 
 
-def create_jurisdiction():
+def create_jurisdiction() -> Jurisdiction:
     Division.objects.create(id="ocd-division/country:us", name="USA")
     j = Jurisdiction.objects.create(id="jid", division_id="ocd-division/country:us")
-    j.legislative_sessions.create(identifier="1899", name="1899")
-    j.legislative_sessions.create(identifier="1900", name="1900")
+    j.legislative_sessions.create(
+        identifier="1899", name="1899", start_date="1899", end_date="1900"
+    )
+    j.legislative_sessions.create(
+        identifier="1900", name="1900", start_date="1900", end_date="1901"
+    )
+    return j
 
 
 def create_org():
@@ -77,7 +82,8 @@ def test_full_bill():
         "Jane Smith", classification="lead sponsor", entity_type="person", primary=True
     )
     bill.add_abstract(
-        "This is an act about axes and taxes and tacks.", note="official",
+        "This is an act about axes and taxes and tacks.",
+        note="official",
     )
     bill.add_document_link(
         "Fiscal Note", "http://example.com/fn.pdf", media_type="application/pdf"
@@ -379,7 +385,7 @@ def test_bill_sponsor_by_identifier():
 
 
 @pytest.mark.django_db
-def test_bill_sponsor_limit_lookup():
+def test_bill_sponsor_limit_lookup_by_jurisdiction():
     create_jurisdiction()
     org = create_org()
 
@@ -413,6 +419,64 @@ def test_bill_sponsor_limit_lookup():
     assert entry.person.birth_date == "1800-01-01"
 
 
+@pytest.mark.django_db
+def test_bill_sponsor_limit_lookup_within_session():
+    j = create_jurisdiction()
+    org = create_org()
+    j.legislative_sessions.create(
+        identifier="2021", name="2021", start_date="2021", end_date="2022"
+    )
+
+    old_bill = ScrapeBill(
+        "HB 1", "1900", "Axe & Tack Tax Act", classification="tax bill", chamber="lower"
+    )
+    old_bill.add_sponsorship(
+        name="Springfield",
+        classification="sponsor",
+        entity_type="person",
+        primary=True,
+    )
+    new_bill = ScrapeBill(
+        "HB 9000",
+        "2021",
+        "Laser Regulations",
+        classification="tax bill",
+        chamber="lower",
+    )
+    new_bill.add_sponsorship(
+        name="Springfield",
+        classification="sponsor",
+        entity_type="person",
+        primary=True,
+    )
+
+    jeb = Person.objects.create(
+        name="Jebediah Springfield", birth_date="1850-01-01", family_name="Springfield"
+    )
+    Membership.objects.create(
+        person_id=jeb.id, organization_id=org.id, end_date="1910-01-01"
+    )
+
+    futuro = Person.objects.create(
+        name="Futuro Springfield", birth_date="2000-01-01", family_name="Springfield"
+    )
+    Membership.objects.create(
+        person_id=futuro.id, organization_id=org.id, start_date="2020-04-01"
+    )
+
+    BillImporter("jid").import_data([old_bill.as_dict(), new_bill.as_dict()])
+
+    # get old bill and ensure Jeb is sponsor
+    old_bill_obj = Bill.objects.get(identifier="HB 1")
+    (entry,) = old_bill_obj.sponsorships.all()
+    assert entry.person.name == jeb.name
+
+    # get new bill and ensure Futuro is sponsor
+    new_bill_obj = Bill.objects.get(identifier="HB 9000")
+    (entry,) = new_bill_obj.sponsorships.all()
+    assert entry.person.name == futuro.name
+
+
 @pytest.mark.django_db
 def test_fix_bill_id():
     create_jurisdiction()
@@ -433,3 +497,36 @@ def test_fix_bill_id():
 
     b = Bill.objects.get()
     assert b.identifier == "HB 1"
+
+
+@pytest.mark.django_db
+def test_bill_duplicate_actions_ordering():
+    create_jurisdiction()
+    create_org()
+
+    def _problem_bill():
+        bill = ScrapeBill(
+            "HB 1",
+            "1900",
+            "Axe & Tack Tax Act",
+            classification="tax bill",
+            chamber="lower",
+        )
+        # two identical actions, and one differs
+        bill.add_action("identical action", "1900-04-01", chamber="lower")
+        bill.add_action("different action", "1900-04-01", chamber="lower")
+        bill.add_action("identical action", "1900-04-01", chamber="lower")
+        return bill
+
+    # import bill
+    bill = _problem_bill()
+    result = BillImporter("jid").import_data([bill.as_dict()])
+    assert result["bill"]["insert"] == 1
+    assert result["bill"]["update"] == 0
+    assert result["bill"]["noop"] == 0
+
+    bill = _problem_bill()
+    result = BillImporter("jid").import_data([bill.as_dict()])
+    assert result["bill"]["insert"] == 0
+    assert result["bill"]["update"] == 0
+    assert result["bill"]["noop"] == 1
