@@ -49,6 +49,16 @@ from .wi import WI
 from .wv import WV
 from .wy import WY
 
+from .dc import DC
+
+from .pr import PR
+from .asm import AS
+from .mp import MP
+from .gu import GU
+from .vi import VI
+
+from .za import ZA
+
 STATES = [
     AK,
     AL,
@@ -101,3 +111,7 @@ STATES = [
     WV,
     WY,
 ]
+
+DISTRICTS = [DC]
+TERRITORIES = [AS, GU, MP, PR, VI]
+INTERNATIONAL = [ZA]
