@@ -1,6 +1,6 @@
 # flake8: noqa
-from .jurisdiction import Jurisdiction, JurisdictionScraper
-from .popolo import Membership, Organization, Person, Post
+from .jurisdiction import State, JurisdictionScraper
+from .popolo import Organization
 from .vote_event import VoteEvent
 from .bill import Bill
 from .event import Event, calculate_window
